Module versioned_tx

Module versioned_tx 

Structs

AccountMeta
Describes a single account read or written by a program during instruction execution.
AddressLookupTable
AddressLookupTableAccount
The definition of address lookup table accounts.
CommitmentConfig
Instruction
A directive for a single invocation of a Solana program.
Keypair
A vanilla Ed25519 key pair
Pubkey
The address of a Solana account.
RpcClient
A client of a remote Solana node.
RpcSendTransactionConfig
Signature
Transaction
An atomically-committed sequence of instructions.
VersionedTransaction
An atomic transaction

Enums

CommitmentLevel
An attribute of a slot. It describes how finalized a block is at some point in time. For example, a slot is said to be at the max level immediately after the cluster recognizes the block at that slot as finalized. When querying the ledger state, use lower levels of commitment to report progress and higher levels to ensure state changes will not be rolled back.
RpcRequest
UiTransactionEncoding
VersionedMessage
Either a legacy message or a v0 message.

Traits

BorshDeserialize
A data-structure that can be de-serialized from binary format by NBOR.
BorshSerialize
A data-structure that can be serialized into binary format by NBOR.
EncodableKey
The EncodableKey trait defines the interface by which cryptographic keys/keypairs are read, written, and derived from sources.
Signer
The Signer trait declares operations that all digital signature providers must support. It is the primary interface by which signers are specified in Transaction signing interfaces

Functions

call_with_lookup_table
Sign and submit a legacy transaction.
create_lookup_table
create a lookup table with an authority account.
extend_lookup_table
extend a lookup table.

Derive Macros

BorshDeserialize

BorshSerialize