Structs
- Account
Meta - Describes a single account read or written by a program during instruction execution.
- Address
Lookup Table - Address
Lookup Table Account - The definition of address lookup table accounts.
- Commitment
Config - Instruction
- A directive for a single invocation of a Solana program.
- Keypair
- A vanilla Ed25519 key pair
- Pubkey
- The address of a Solana account.
- RpcClient
- A client of a remote Solana node.
- RpcSend
Transaction Config - Signature
- Transaction
- An atomically-committed sequence of instructions.
- Versioned
Transaction - An atomic transaction
Enums
- Commitment
Level - An attribute of a slot. It describes how finalized a block is at some point in time. For example, a slot is said to be at the max level immediately after the cluster recognizes the block at that slot as finalized. When querying the ledger state, use lower levels of commitment to report progress and higher levels to ensure state changes will not be rolled back.
- RpcRequest
- UiTransaction
Encoding - Versioned
Message - Either a legacy message or a v0 message.
Traits
- Borsh
Deserialize - A data-structure that can be de-serialized from binary format by NBOR.
- Borsh
Serialize - A data-structure that can be serialized into binary format by NBOR.
- Encodable
Key - The
EncodableKeytrait defines the interface by which cryptographic keys/keypairs are read, written, and derived from sources. - Signer
- The
Signertrait declares operations that all digital signature providers must support. It is the primary interface by which signers are specified inTransactionsigning interfaces
Functions
- call_
with_ lookup_ table - Sign and submit a legacy transaction.
- create_
lookup_ table - create a lookup table with an authority account.
- extend_
lookup_ table - extend a lookup table.